#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QTcpServer>
#include <QTcpSocket>
#include <QXmlSimpleReader>
#include <lfrxmlhandler.h>
#include <lfrxmlwriter.h>
#include <mainwindowui.h>
#include "tmpackettoread.h"
#include "wfpacket.h"

class MainWindow : public QWidget
{
    Q_OBJECT
    
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void displayNetworkInterfaces();
    void processIncomingData(char *data, unsigned int size);
    void initSocketStatesList();
    void preProcessPacket(TMPacketToRead *packet);
    void buildWFAndDisplay(TMPacketToRead *packet, WFPacket *wfPacket, unsigned char num_page);
    char fromAsciiToChar(char value);

private:
    QList<TMPacketToRead*> generalCCSDSPacketStore;

    QTcpServer *analyserSGSEServerTC;
    QTcpServer *analyserSGSEServerTM;
    QTcpSocket *socketTC;
    QTcpSocket *socketTM;
    QTcpSocket *socketEchoServer;

    unsigned int totalOfBytes;

    QXmlSimpleReader xmlReader;
    QXmlInputSource *sourceTC;
    QXmlInputSource *sourceTMechoBridge;
    LFRXmlHandler *xmlHandler;

    QList<QString> socketStates;

    char *buffer;

    MainWindowUI *UI;

    LFRXmlWriter *lfrXmlWriter;

    WFPacket wfPacketNormal[4];

signals:
    void socketTMHasChanged(QTcpSocket *socket);

public slots:
    void displayOnConsole(QString message);
    void listenOnTCTMPorts();
    void testTCTMPorts();
    void newConnectionOnTCServer();
    void newConnectionOnTMServer();
    void readDataOnTCPort();
    void readDataOnTMPort();
    void readDataOnSocketEchoServer();
    void openEchoServer();
    void socket_TMEcho_ServerHasChanged();
};

#endif // MAINWINDOW_H
